==> Paws-0.37.tar.gz: Paws-0.37/lib/Paws/GuardDuty/DisassociateFromMasterAccount.pm <==

package Paws::GuardDuty::DisassociateFromMasterAccount;
  use Moose;
  has DetectorId => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'detectorId', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DisassociateFromMasterAccount');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/detector/{detectorId}/master/disassociate');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'POST');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::GuardDuty::DisassociateFromMasterAccountResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::GuardDuty::DisassociateFromMasterAccount - Arguments for method DisassociateFromMasterAccount on L<Paws::GuardDuty>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DisassociateFromMasterAccount on the
L<Amazon GuardDuty|Paws::GuardDuty> service. Use the attributes of this class
as arguments to method DisassociateFromMasterAccount.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DisassociateFromMasterAccount.

=head1 SYNOPSIS

    my $guardduty = Paws->service('GuardDuty');
    my $DisassociateFromMasterAccountResponse =
      $guardduty->DisassociateFromMasterAccount(
      DetectorId => 'My__string',

      );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://aws.amazon.com/documentation/>

=head1 ATTRIBUTES


=head2 B<REQUIRED> DetectorId => Str

The unique ID of the detector of the GuardDuty member account.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DisassociateFromMasterAccount in L<Paws::GuardDuty>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.39.tar.gz: Paws-0.39/lib/Paws/GuardDuty/DisassociateFromMasterAccount.pm <==

package Paws::GuardDuty::DisassociateFromMasterAccount;
  use Moose;
  has DetectorId => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'detectorId', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DisassociateFromMasterAccount');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/detector/{detectorId}/master/disassociate');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'POST');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::GuardDuty::DisassociateFromMasterAccountResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::GuardDuty::DisassociateFromMasterAccount - Arguments for method DisassociateFromMasterAccount on L<Paws::GuardDuty>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DisassociateFromMasterAccount on the
L<Amazon GuardDuty|Paws::GuardDuty> service. Use the attributes of this class
as arguments to method DisassociateFromMasterAccount.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DisassociateFromMasterAccount.

=head1 SYNOPSIS

    my $guardduty = Paws->service('GuardDuty');
    my $DisassociateFromMasterAccountResponse =
      $guardduty->DisassociateFromMasterAccount(
      DetectorId => 'My__string',

      );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/guardduty/DisassociateFromMasterAccount>

=head1 ATTRIBUTES


=head2 B<REQUIRED> DetectorId => Str

The unique ID of the detector of the GuardDuty member account.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DisassociateFromMasterAccount in L<Paws::GuardDuty>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
